@@ -3,7 +3,7 @@
 import os
 import sys
 from typing import List, Dict, Any, Optional
-from pydantic_ai import Agent, RunContext
+from pydantic_ai import Agent, RunContext, WebSearchTool
 from pydantic_ai.models.anthropic import AnthropicModel
 from .utils import (
     scan_directory,
@@ -11,7 +11,8 @@ from .utils import (
     write_file_safe,
     get_project_summary,
     is_blank_project,
-    extract_code_blocks
+    extract_code_blocks,
+    PerformanceMetrics
 )
 from .config import WYN360Config
 
@@ -58,6 +59,9 @@ class WYN360Agent:
         self.request_count = 0
         self.token_history: List[Dict[str, Any]] = []
 
+        # Performance metrics tracking (Phase 10.2)
+        self.performance_metrics = PerformanceMetrics()
+
         # Set API key in environment for pydantic-ai to use
         os.environ['ANTHROPIC_API_KEY'] = api_key
 
@@ -81,7 +85,19 @@ class WYN360Agent:
                 self.search_files,
                 self.delete_file,
                 self.move_file,
-                self.create_directory
+                self.create_directory,
+                # HuggingFace tools
+                self.check_hf_authentication,
+                self.authenticate_hf,
+                self.create_hf_readme,
+                self.create_hf_space,
+                self.push_to_hf_space,
+                # Test Generation tool
+                self.generate_tests
+            ],
+            builtin_tools=[
+                # Phase 11.1: Web Search - Live internet access
+                WebSearchTool(max_uses=5)
             ],
             retries=0  # No retries - show errors immediately to model for correction
         )
@@ -183,6 +199,142 @@ Notes:
 - Commands run with user's full permissions in the current directory
 - Default timeout is 300 seconds (5 minutes), adjust if needed
 - Always preserve the success/failure indicator from tool output
+
+**HuggingFace Integration (Phase 2 - Full Deployment):**
+
+You can help users deploy apps to HuggingFace Spaces automatically!
+
+**Complete Workflow when user says "push to huggingface" or "deploy to HF":**
+
+1. **Check Authentication (ONLY ONCE per session)**:
+   - Call check_hf_authentication() ONE TIME only
+   - If it returns "✓ Authenticated", NEVER check again - remember they're authenticated
+   - If not authenticated, ask for token and use authenticate_hf(token)
+   - Once authenticated, proceed to step 2
+
+2. **Gather Information (if not already provided)**:
+   - Space name in format "username/repo-name" (e.g., "eagle0504/test-echo-bot")
+   - App title for the Space
+   - SDK type (streamlit, gradio, docker, or static)
+   - App directory path (where app.py and requirements.txt are located)
+
+3. **Deploy to HuggingFace (Automatic)**:
+   a. Navigate to the app directory if needed
+   b. Create README.md with create_hf_readme(title, sdk):
+      - For Streamlit: sdk="streamlit", app_file="app.py"
+      - For Gradio: sdk="gradio", app_file="app.py"
+   c. Create Space with create_hf_space(space_name, sdk):
+      - Returns Space URL or "already exists" message
+   d. Upload files with push_to_hf_space(space_name, directory):
+      - Uploads all files in directory to the Space
+      - Returns live Space URL
+
+4. **Completion**:
+   - Confirm files were uploaded successfully
+   - Provide the live Space URL: https://huggingface.co/spaces/{space_name}
+   - Tell user "🎉 Your app is live!"
+
+**CRITICAL - Avoid Authentication Loops:**
+- Do NOT call check_hf_authentication() multiple times in one conversation
+- Once user is authenticated, trust it and proceed
+- If user provided token in previous messages, they are authenticated - don't ask again
+- If user gave you all details (token, space name, title, directory), proceed directly to deployment
+
+**Important Notes:**
+- Space names MUST be in "username/repo-name" format (e.g., "eagle0504/test-echo-bot")
+- README.md needs proper YAML frontmatter for Spaces to work
+- For Streamlit: typically need app.py and requirements.txt in same directory
+- The entire directory gets uploaded, so make sure only necessary files are included
+- If Space already exists, files will be updated (not replaced)
+
+**Test Generation (Phase 7.2):**
+
+You can automatically generate unit tests for Python files!
+
+**When to use generate_tests:**
+- User asks "generate tests for [file]"
+- User says "create test file for [file]"
+- User wants pytest tests for their code
+
+**Workflow:**
+1. Confirm the Python file path with user
+2. Use generate_tests(file_path) to analyze and generate tests
+3. Explain what was generated (functions, classes covered)
+4. Remind user that generated tests are templates with TODO markers
+5. Suggest they fill in actual test logic and assertions
+
+**What it does:**
+- Parses Python file using AST (safe, doesn't execute code)
+- Finds all public functions and classes
+- Generates pytest test stubs with docstrings
+- Creates test_{filename}.py file
+- Includes TODO comments for user to fill in
+
+**Important:**
+- Generated tests are TEMPLATES - they have pass statements and TODO comments
+- User must add actual test logic and assertions
+- Tests won't fail initially - they need implementation
+- Good starting point to save time on test structure
+
+**Web Search Capability (Phase 11.1):**
+
+You now have access to real-time web search for current information!
+
+**WHEN TO USE WEB SEARCH:**
+
+1. **Weather Queries:**
+   - User asks: "What's the weather?" or "weather today"
+   - ACTION: Ask for location first if not provided
+   - User provides location → Search and display results with source
+   - Example: "What's the weather in New York?" → Search for current weather
+
+2. **Website Reading:**
+   - User provides URL: "Read https://example.com" or "What's on that website?"
+   - ACTION: Fetch content and provide comprehensive summary
+   - Always include key points and relevant information
+   - Example: "Read the Python docs on async" → Fetch and summarize
+
+3. **Current Information:**
+   - Latest documentation, recent news/events, real-time data
+   - Package/library versions and updates
+   - Current best practices and trends
+   - Examples:
+     - "What's new in Python 3.13?"
+     - "Latest React features"
+     - "Current best practices for FastAPI"
+
+**CITATION FORMAT:**
+Always include:
+- Source URL
+- Relevant excerpt or summary
+- Publication date/last updated (if available)
+
+Example:
+```
+According to [Source Name](URL):
+"[Relevant excerpt]"
+(Last updated: YYYY-MM-DD)
+```
+
+**AVOID WEB SEARCH FOR:**
+- Code generation (use your training data)
+- File operations (use read_file, write_file)
+- Local project queries (use list_files, get_project_info)
+- Git operations (use git_status, git_diff, git_log)
+- General programming concepts you already know
+
+**COST AWARENESS:**
+- Web search costs $10 per 1,000 searches + token costs
+- Limited to 5 searches per session by default
+- Use judiciously - only when truly needed for current/live information
+
+**Examples:**
+- ✅ "What's the weather in San Francisco?" → Use web search
+- ✅ "Read https://python.org/downloads" → Use web search
+- ✅ "What are the latest security vulnerabilities in Node.js?" → Use web search
+- ❌ "Write a FastAPI app" → Don't use web search (use training data)
+- ❌ "Show me the files in this project" → Don't use web search (use list_files)
+- ❌ "What's git?" → Don't use web search (you know this)
 """
 
         # Add custom instructions from config if available
@@ -216,6 +368,10 @@ Notes:
             File contents or error message
         """
         success, content = read_file_safe(file_path)
+
+        # Track tool call
+        self.performance_metrics.track_tool_call("read_file", success)
+
         if success:
             return f"Contents of {file_path}:\n\n{content}"
         else:
@@ -286,6 +442,9 @@ Notes:
             # Try to write the file
             success, message = write_file_safe(file_path, content, overwrite)
 
+            # Track tool call
+            self.performance_metrics.track_tool_call("write_file", success)
+
             # If file exists and overwrite is False, provide clear guidance
             if not success and "already exists" in message:
                 return f"{message}\n\nNote: If you want to update this file, you must explicitly set overwrite=True in your next write_file call."
@@ -312,6 +471,9 @@ Notes:
         """
         files = scan_directory(directory)
 
+        # Track tool call (list_files always succeeds)
+        self.performance_metrics.track_tool_call("list_files", True)
+
         result = "Files in project:\n\n"
         for category, file_list in files.items():
             if file_list:
@@ -394,6 +556,9 @@ Notes:
 
         success, output, return_code = execute_command_safe(command, timeout)
 
+        # Track tool call
+        self.performance_metrics.track_tool_call("execute_command", success)
+
         if success:
             result = f"✅ Command executed successfully (exit code {return_code})\n\n"
             result += f"Output:\n{output}"
@@ -413,6 +578,9 @@ Notes:
         from .utils import execute_command_safe
         success, output, return_code = execute_command_safe("git status", timeout=10)
 
+        # Track tool call
+        self.performance_metrics.track_tool_call("git_status", success)
+
         if success:
             return f"Git Status:\n\n{output}"
         else:
@@ -510,6 +678,10 @@ Notes:
 
         success, output, return_code = execute_command_safe(command, timeout=20)
 
+        # Track tool call (grep returns 1 for no matches, which is not really a failure)
+        tool_success = success or return_code == 1
+        self.performance_metrics.track_tool_call("search_files", tool_success)
+
         if success:
             if not output.strip():
                 return f"No matches found for pattern '{pattern}' in {file_pattern} files."
@@ -634,6 +806,393 @@ Notes:
         except Exception as e:
             return f"Error creating directory '{dir_path}': {str(e)}"
 
+    # ==================== HuggingFace Integration Tools ====================
+
+    async def check_hf_authentication(self, ctx: RunContext[None]) -> str:
+        """
+        Check if user is authenticated with HuggingFace.
+
+        Returns authentication status and username if authenticated.
+
+        Examples:
+            - "check if I'm logged into huggingface"
+            - "am I authenticated with HF?"
+        """
+        from .utils import execute_command_safe, extract_username_from_hf_whoami
+
+        # Check environment variable
+        hf_token = os.getenv('HF_TOKEN')
+
+        # Try hf CLI whoami
+        success, output, code = execute_command_safe("hf auth whoami", timeout=10)
+
+        if success and "username" in output.lower():
+            username = extract_username_from_hf_whoami(output)
+            return f"✓ Authenticated with HuggingFace as '{username}'"
+        elif hf_token:
+            # Token exists but CLI not authenticated - try to authenticate automatically
+            os.environ['HF_TOKEN'] = hf_token
+            success2, output2, code2 = execute_command_safe(
+                "hf auth login --token $HF_TOKEN",
+                timeout=30
+            )
+            if success2 or "token is valid" in output2.lower():
+                success3, output3, _ = execute_command_safe("hf auth whoami", timeout=10)
+                username = extract_username_from_hf_whoami(output3) if success3 else "user"
+                return f"✓ Authenticated with HuggingFace as '{username}' (auto-authenticated using HF_TOKEN from environment)"
+            else:
+                return f"❌ HF_TOKEN found in environment but authentication failed. Error: {output2[:200]}"
+        else:
+            return ("Not authenticated with HuggingFace. To push code to HuggingFace Spaces, I need your access token.\n\n"
+                   "You can get a token from: https://huggingface.co/settings/tokens\n\n"
+                   "Then either:\n"
+                   "1. Export it before starting: export HF_TOKEN=your_token\n"
+                   "2. Provide it to me in chat and I'll authenticate you")
+
+    async def authenticate_hf(self, ctx: RunContext[None], token: str) -> str:
+        """
+        Authenticate with HuggingFace using provided token.
+
+        Args:
+            token: HuggingFace access token (starts with 'hf_')
+
+        Returns:
+            Status message with username if successful
+
+        Examples:
+            - "authenticate with HF using token hf_xxxxx"
+            - "login to huggingface with hf_xxxxx"
+        """
+        from .utils import execute_command_safe, extract_username_from_hf_whoami
+
+        # Validate token format
+        if not token or len(token) < 10:
+            return "❌ Invalid token format. HuggingFace tokens should be longer."
+
+        # Save token to environment for this session
+        os.environ['HF_TOKEN'] = token
+
+        # Authenticate via CLI using the token environment variable
+        success, output, code = execute_command_safe(
+            "hf auth login --token $HF_TOKEN",
+            timeout=30
+        )
+
+        if success or "token is valid" in output.lower():
+            # Get username
+            success2, output2, _ = execute_command_safe("hf auth whoami", timeout=10)
+            username = extract_username_from_hf_whoami(output2) if success2 else "user"
+            return f"✓ Successfully authenticated with HuggingFace as '{username}'\n\nYou can now push code to Spaces!"
+        else:
+            return f"❌ Authentication failed. Please check your token.\n\nError: {output[:200]}"
+
+    async def create_hf_readme(
+        self,
+        ctx: RunContext[None],
+        title: str,
+        sdk: str = "streamlit",
+        sdk_version: str = "1.34.0",
+        app_file: str = "app.py",
+        emoji: str = "🔥",
+        color_from: str = "indigo",
+        color_to: str = "green",
+        license: str = "mit"
+    ) -> str:
+        """
+        Generate README.md with HuggingFace Space frontmatter.
+
+        Args:
+            title: Space title
+            sdk: SDK type (streamlit, gradio, docker, static)
+            sdk_version: SDK version
+            app_file: Main app file (app.py or Home.py for streamlit)
+            emoji: Space emoji
+            color_from: Gradient start color
+            color_to: Gradient end color
+            license: License type
+
+        Returns:
+            Path to created README.md
+
+        Examples:
+            - "create a README for my streamlit app called 'Echo Bot'"
+            - "generate huggingface README with title 'Data Viz'"
+        """
+        from .utils import write_file_safe
+
+        readme_content = f"""---
+title: {title}
+emoji: {emoji}
+colorFrom: {color_from}
+colorTo: {color_to}
+sdk: {sdk}
+sdk_version: {sdk_version}
+app_file: {app_file}
+pinned: false
+license: {license}
+---
+
+# {title}
+
+This Space was created with WYN360-CLI.
+
+Check out the configuration reference at https://huggingface.co/docs/hub/spaces-config-reference
+"""
+
+        # Write README.md
+        success, msg = write_file_safe("README.md", readme_content, overwrite=True)
+
+        if success:
+            return f"✓ Created README.md with {sdk} Space configuration (title: {title})"
+        else:
+            return f"❌ Failed to create README.md: {msg}"
+
+    async def create_hf_space(
+        self,
+        ctx: RunContext[None],
+        space_name: str,
+        sdk: str = "streamlit",
+        private: bool = False
+    ) -> str:
+        """
+        Create a HuggingFace Space repository.
+
+        Args:
+            space_name: Space name in format "username/repo-name" (e.g., "eagle0504/test-echo-bot")
+            sdk: SDK type (streamlit, gradio, docker, static)
+            private: Whether the Space should be private (default: False)
+
+        Returns:
+            Success message with Space URL or error message
+
+        Examples:
+            - "create huggingface space eagle0504/my-app with streamlit"
+            - "create private space myuser/secret-app"
+        """
+        from .utils import execute_command_safe
+
+        # Validate space name format
+        if '/' not in space_name:
+            return f"❌ Invalid space name format. Must be 'username/repo-name' (e.g., 'eagle0504/test-echo-bot'), got: {space_name}"
+
+        # Build command
+        cmd = f"hf repo create {space_name} --type=space --space-sdk={sdk}"
+        if private:
+            cmd += " --private"
+
+        # Execute command
+        success, output, code = execute_command_safe(cmd, timeout=60)
+
+        if success or "already exists" in output.lower():
+            space_url = f"https://huggingface.co/spaces/{space_name}"
+            if "already exists" in output.lower():
+                return f"✓ Space '{space_name}' already exists at {space_url}"
+            else:
+                return f"✓ Successfully created Space '{space_name}' at {space_url}"
+        else:
+            return f"❌ Failed to create Space '{space_name}'\n\nError: {output[:300]}"
+
+    async def push_to_hf_space(
+        self,
+        ctx: RunContext[None],
+        space_name: str,
+        directory: str = "."
+    ) -> str:
+        """
+        Upload files to HuggingFace Space.
+
+        Args:
+            space_name: Space name in format "username/repo-name"
+            directory: Directory to upload (default: current directory)
+
+        Returns:
+            Success message or error message
+
+        Examples:
+            - "push current directory to eagle0504/test-echo-bot"
+            - "upload test_echo folder to myuser/my-app"
+        """
+        from .utils import execute_command_safe
+        from pathlib import Path
+
+        # Validate space name format
+        if '/' not in space_name:
+            return f"❌ Invalid space name format. Must be 'username/repo-name', got: {space_name}"
+
+        # Validate directory exists
+        dir_path = Path(directory)
+        if not dir_path.exists():
+            return f"❌ Directory not found: {directory}"
+
+        # Check for required files
+        app_files = list(dir_path.glob("app.py")) + list(dir_path.glob("Home.py"))
+        if not app_files:
+            return f"⚠️  Warning: No app.py or Home.py found in {directory}. Make sure this is the correct directory."
+
+        # Upload entire directory to Space
+        cmd = f"hf upload {space_name} {directory} . --repo-type=space"
+
+        # Execute upload
+        success, output, code = execute_command_safe(cmd, timeout=300)
+
+        if success:
+            space_url = f"https://huggingface.co/spaces/{space_name}"
+            return f"✓ Successfully uploaded files to Space '{space_name}'\n\n🎉 Your app is live at: {space_url}"
+        else:
+            # Check if it's a quota/permission error
+            if "quota" in output.lower() or "limit" in output.lower():
+                return f"❌ Upload failed: You may have reached your HuggingFace storage quota.\n\nError: {output[:300]}"
+            elif "not found" in output.lower() or "doesn't exist" in output.lower():
+                return f"❌ Upload failed: Space '{space_name}' doesn't exist. Create it first with create_hf_space.\n\nError: {output[:300]}"
+            else:
+                return f"❌ Upload failed for Space '{space_name}'\n\nError: {output[:300]}"
+
+    # ==================== Test Generation Tool ====================
+
+    async def generate_tests(
+        self,
+        ctx: RunContext[None],
+        file_path: str,
+        test_file_path: str = None
+    ) -> str:
+        """
+        Generate unit tests for a Python file.
+
+        Analyzes the Python file and creates pytest test cases for functions and classes.
+
+        Args:
+            file_path: Path to Python file to generate tests for
+            test_file_path: Optional path for test file (default: test_{filename}.py)
+
+        Returns:
+            Success message with test file path or error message
+
+        Examples:
+            - "generate tests for calculator.py"
+            - "create tests for utils/helpers.py"
+        """
+        import ast
+        from pathlib import Path
+        from .utils import read_file_safe, write_file_safe
+
+        # Validate file exists
+        file_p = Path(file_path)
+        if not file_p.exists():
+            return f"❌ File not found: {file_path}"
+
+        if not file_p.suffix == '.py':
+            return f"❌ File must be a Python file (.py), got: {file_p.suffix}"
+
+        # Read the file
+        success, content = read_file_safe(str(file_p))
+        if not success:
+            return f"❌ Failed to read file: {content}"
+
+        # Parse the Python code
+        try:
+            tree = ast.parse(content)
+        except SyntaxError as e:
+            return f"❌ Syntax error in {file_path}: {str(e)}"
+
+        # Extract functions and classes
+        functions = []
+        classes = []
+
+        for node in ast.walk(tree):
+            if isinstance(node, ast.FunctionDef):
+                # Skip private functions and methods inside classes
+                if not node.name.startswith('_'):
+                    # Check if it's a module-level function
+                    parent_is_module = any(
+                        isinstance(parent, ast.Module)
+                        for parent in ast.walk(tree)
+                        if hasattr(parent, 'body') and node in getattr(parent, 'body', [])
+                    )
+                    if parent_is_module or node.col_offset == 0:
+                        functions.append({
+                            'name': node.name,
+                            'args': [arg.arg for arg in node.args.args if arg.arg != 'self'],
+                            'lineno': node.lineno
+                        })
+            elif isinstance(node, ast.ClassDef):
+                if not node.name.startswith('_'):
+                    methods = [
+                        n.name for n in node.body
+                        if isinstance(n, ast.FunctionDef) and not n.name.startswith('_')
+                    ]
+                    classes.append({
+                        'name': node.name,
+                        'methods': methods,
+                        'lineno': node.lineno
+                    })
+
+        if not functions and not classes:
+            return f"⚠️  No testable functions or classes found in {file_path}"
+
+        # Determine test file path
+        if test_file_path is None:
+            test_file_path = file_p.parent / f"test_{file_p.name}"
+        else:
+            test_file_path = Path(test_file_path)
+
+        # Generate test code
+        module_name = file_p.stem
+        test_code = f'''"""Unit tests for {module_name}.py"""
+
+import pytest
+from {module_name} import {', '.join([f['name'] for f in functions] + [c['name'] for c in classes])}
+
+
+'''
+
+        # Generate test functions
+        for func in functions:
+            test_code += f'''def test_{func['name']}_basic():
+    """Test {func['name']} with basic inputs"""
+    # TODO: Add test implementation
+    # Example: result = {func['name']}({', '.join(['arg' + str(i+1) for i in range(len(func['args']))])})
+    # assert result == expected_value
+    pass
+
+
+'''
+
+        # Generate test classes
+        for cls in classes:
+            test_code += f'''class Test{cls['name']}:
+    """Tests for {cls['name']} class"""
+
+    def test_initialization(self):
+        """Test {cls['name']} initialization"""
+        # TODO: Add test implementation
+        # obj = {cls['name']}()
+        # assert obj is not None
+        pass
+
+'''
+            for method in cls['methods'][:3]:  # Limit to first 3 methods
+                test_code += f'''    def test_{method}(self):
+        """Test {cls['name']}.{method}() method"""
+        # TODO: Add test implementation
+        pass
+
+'''
+
+        # Write test file
+        success, msg = write_file_safe(str(test_file_path), test_code, overwrite=False)
+
+        if success:
+            summary = f"✓ Generated test file: {test_file_path}\n\n"
+            summary += f"Test coverage:\n"
+            summary += f"  - {len(functions)} function(s): {', '.join([f['name'] for f in functions])}\n" if functions else ""
+            summary += f"  - {len(classes)} class(es): {', '.join([c['name'] for c in classes])}\n" if classes else ""
+            summary += f"\nTotal tests generated: {len(functions) + sum(1 + len(c['methods'][:3]) for c in classes)}\n"
+            summary += f"\n⚠️  Note: Generated tests are templates with TODO markers."
+            summary += f"\n    You need to fill in actual test logic and assertions."
+            return summary
+        else:
+            return f"❌ Failed to write test file: {msg}"
+
     async def chat(self, user_message: str) -> str:
         """
         Process a user message and generate a response.
@@ -700,6 +1259,8 @@ Notes:
         Returns:
             Complete response text from the agent
         """
+        import time
+
         try:
             # Add user message to history
             self.conversation_history.append({
@@ -707,10 +1268,17 @@ Notes:
                 "content": user_message
             })
 
+            # Track response time
+            start_time = time.time()
+
             # Use run() to get complete response (not run_stream)
             # This ensures tools execute properly
             result = await self.agent.run(user_message)
 
+            # Record response time
+            duration = time.time() - start_time
+            self.performance_metrics.track_request_time(duration)
+
             # Extract response text
             response_text = getattr(result, 'data', None) or getattr(result, 'output', str(result))
             if not isinstance(response_text, str):
@@ -745,6 +1313,10 @@ Notes:
             return response_text
 
         except Exception as e:
+            # Track error
+            error_type = type(e).__name__
+            self.performance_metrics.track_error(error_type, str(e))
+
             error_msg = f"\n\nAn error occurred: {str(e)}"
             return error_msg
 
@@ -773,12 +1345,13 @@ Notes:
             return 'script.py'
 
     def clear_history(self) -> None:
-        """Clear conversation history and reset token counters."""
+        """Clear conversation history and reset token counters and performance metrics."""
         self.conversation_history = []
         self.total_input_tokens = 0
         self.total_output_tokens = 0
         self.request_count = 0
         self.token_history = []
+        self.performance_metrics = PerformanceMetrics()  # Reset performance metrics
 
     def get_history(self) -> List[Dict[str, str]]:
         """Get current conversation history."""
@@ -805,6 +1378,7 @@ Notes:
                 "total_output_tokens": self.total_output_tokens,
                 "request_count": self.request_count,
                 "token_history": self.token_history,
+                "performance_metrics": self.performance_metrics.to_dict(),
                 "timestamp": str(os.popen('date').read().strip())
             }
 
@@ -847,6 +1421,10 @@ Notes:
             self.request_count = session_data.get("request_count", 0)
             self.token_history = session_data.get("token_history", [])
 
+            # Load performance metrics if available
+            if "performance_metrics" in session_data:
+                self.performance_metrics.from_dict(session_data["performance_metrics"])
+
             return True
         except Exception as e:
             print(f"Error loading session: {e}")
@@ -877,6 +1455,15 @@ Notes:
             "output_cost": self.total_output_tokens / 1_000_000 * 15.0,
         }
 
+    def get_performance_stats(self) -> Dict[str, Any]:
+        """
+        Get performance metrics statistics.
+
+        Returns:
+            Dictionary with performance metrics
+        """
+        return self.performance_metrics.get_statistics()
+
     def switch_model(self, model_name: str) -> bool:
         """
         Switch to a different Claude model mid-session.
