@@ -20,7 +20,7 @@ console_width = max(80, min(200, terminal_width))
 console = Console(width=console_width, force_terminal=True)
 
 
-@click.command()
+@click.command(context_settings=dict(help_option_names=['-h', '--help']))
 @click.option(
     '--api-key',
     default=None,
@@ -36,6 +36,67 @@ def main(api_key, model):
     WYN360 - An intelligent AI coding assistant CLI tool.
 
     Interact with Claude to build projects, generate code, and improve your codebase.
+
+    \b
+    QUICK START:
+      $ export ANTHROPIC_API_KEY=your_api_key
+      $ wyn360
+      You: Create a Streamlit chatbot
+      WYN360: [Generates complete app.py with code]
+
+    \b
+    SLASH COMMANDS (use inside session):
+      /clear          Clear conversation history and reset metrics
+      /history        Show conversation history
+      /save <file>    Save session to JSON file
+      /load <file>    Load previous session
+      /tokens         Show token usage and costs
+      /stats          Show performance metrics (NEW in v0.3.19!)
+      /model [name]   Show/switch AI model (haiku/sonnet/opus)
+      /config         Show current configuration
+      /help           Show detailed help inside session
+
+    \b
+    AVAILABLE TOOLS (AI can use automatically):
+      File Operations:
+        - read_file, write_file, list_files, delete_file, move_file
+        - create_directory, get_project_info
+
+      Code Operations:
+        - execute_command (run scripts, install packages)
+        - search_files (grep code patterns)
+        - generate_tests (auto-generate pytest tests)
+
+      Git Operations:
+        - git_status, git_diff, git_log, git_branch
+
+      HuggingFace Integration:
+        - check_hf_authentication, authenticate_hf
+        - create_hf_readme, create_hf_space, push_to_hf_space
+
+      Web Search (NEW in v0.3.21):
+        - web_search (weather, URLs, current info)
+        - Real-time internet access with proper citations
+        - Limited to 5 searches per session ($0.01 per search)
+
+    \b
+    EXAMPLES:
+      # Start with different models
+      $ wyn360 --model haiku              # Fast & cheap
+      $ wyn360 --model sonnet             # Balanced (default)
+      $ wyn360 --model opus               # Most capable
+
+      # Quick commands
+      $ wyn360 --api-key sk-ant-...       # Provide API key directly
+
+    \b
+    DOCUMENTATION:
+      PyPI:        https://pypi.org/project/wyn360-cli/
+      GitHub:      https://github.com/yiqiao-yin/wyn360-cli
+      Use Cases:   See USE_CASES.md for detailed examples
+      Get API Key: https://console.anthropic.com/
+
+    Version: 0.3.21
     """
     # Load environment variables from .env file if it exists
     load_dotenv()
@@ -196,6 +257,98 @@ def handle_slash_command(command: str, agent: WYN360Agent) -> tuple[bool, str]:
         console.print(table)
         return True, ""
 
+    elif cmd == "stats":
+        # Get both token stats and performance stats
+        token_stats = agent.get_token_stats()
+        perf_stats = agent.get_performance_stats()
+
+        from rich.table import Table
+        from rich.panel import Panel
+        from rich.columns import Columns
+
+        # Token Usage Table
+        token_table = Table(title="Token Usage", show_header=False)
+        token_table.add_column("Metric", style="cyan")
+        token_table.add_column("Value", style="yellow")
+
+        token_table.add_row("Total Requests", str(token_stats["total_requests"]))
+        token_table.add_row("Input Tokens", f"{token_stats['total_input_tokens']:,}")
+        token_table.add_row("Output Tokens", f"{token_stats['total_output_tokens']:,}")
+        token_table.add_row("Total Cost", f"${token_stats['total_cost']:.4f}")
+
+        # Performance Table
+        perf_table = Table(title="Performance Metrics", show_header=False)
+        perf_table.add_column("Metric", style="cyan")
+        perf_table.add_column("Value", style="yellow")
+
+        # Session duration
+        duration = perf_stats["session_duration_seconds"]
+        hours = int(duration // 3600)
+        minutes = int((duration % 3600) // 60)
+        seconds = int(duration % 60)
+        if hours > 0:
+            duration_str = f"{hours}h {minutes}m {seconds}s"
+        elif minutes > 0:
+            duration_str = f"{minutes}m {seconds}s"
+        else:
+            duration_str = f"{seconds}s"
+
+        perf_table.add_row("Session Duration", duration_str)
+        perf_table.add_row("Avg Response Time", f"{perf_stats['avg_response_time']:.2f}s")
+        perf_table.add_row("Min Response Time", f"{perf_stats['min_response_time']:.2f}s")
+        perf_table.add_row("Max Response Time", f"{perf_stats['max_response_time']:.2f}s")
+        perf_table.add_row("Error Count", str(perf_stats['error_count']))
+
+        # Tool Usage Table
+        tool_table = Table(title="Tool Usage", show_header=False)
+        tool_table.add_column("Metric", style="cyan")
+        tool_table.add_column("Value", style="yellow")
+
+        tool_table.add_row("Total Tool Calls", str(perf_stats['total_tool_calls']))
+        tool_table.add_row("Successful Calls", str(perf_stats['successful_tool_calls']))
+        tool_table.add_row("Failed Calls", str(perf_stats['failed_tool_calls']))
+        tool_table.add_row("Success Rate", f"{perf_stats['tool_success_rate']:.1f}%")
+
+        # Print all tables
+        console.print()
+        console.print(Columns([token_table, perf_table]))
+        console.print()
+        console.print(tool_table)
+
+        # Show most used tools if any
+        if perf_stats['most_used_tools']:
+            console.print()
+            tools_list = Table(title="Most Used Tools", show_header=True)
+            tools_list.add_column("Tool", style="cyan")
+            tools_list.add_column("Success", style="green")
+            tools_list.add_column("Failed", style="red")
+            tools_list.add_column("Total", style="yellow")
+
+            for tool_name, stats in perf_stats['most_used_tools']:
+                total = stats['success'] + stats['failed']
+                tools_list.add_row(
+                    tool_name,
+                    str(stats['success']),
+                    str(stats['failed']),
+                    str(total)
+                )
+
+            console.print(tools_list)
+
+        # Show error summary if any
+        if perf_stats['error_types']:
+            console.print()
+            error_table = Table(title="Error Summary", show_header=True)
+            error_table.add_column("Error Type", style="red")
+            error_table.add_column("Count", style="yellow")
+
+            for error_type, count in perf_stats['error_types'].items():
+                error_table.add_row(error_type, str(count))
+
+            console.print(error_table)
+
+        return True, ""
+
     elif cmd == "model":
         if not arg:
             # Show current model info
@@ -304,6 +457,7 @@ def handle_slash_command(command: str, agent: WYN360Agent) -> tuple[bool, str]:
   [bold green]/save <file>[/bold green]     Save session to JSON file
   [bold green]/load <file>[/bold green]     Load session from JSON file
   [bold green]/tokens[/bold green]           Show token usage statistics
+  [bold green]/stats[/bold green]            Show comprehensive performance metrics
   [bold green]/model [name][/bold green]    Show/switch AI model (haiku/sonnet/opus)
   [bold green]/config[/bold green]           Show current configuration
   [bold green]/help[/bold green]             Show this help message
@@ -312,6 +466,7 @@ def handle_slash_command(command: str, agent: WYN360Agent) -> tuple[bool, str]:
   /save my_session.json       Save current conversation
   /load my_session.json       Continue previous conversation
   /tokens                     Check how much you've spent
+  /stats                      View performance metrics and tool usage
   /model                      Show current model info
   /model haiku                Switch to Haiku (fast & cheap)
   /model opus                 Switch to Opus (most capable)
@@ -321,6 +476,7 @@ def handle_slash_command(command: str, agent: WYN360Agent) -> tuple[bool, str]:
   • Use /clear if costs are getting high
   • Save important sessions for later reference
   • Token estimates are approximate (±10%)
+  • Use /stats to monitor response times and tool performance
 """
         console.print(help_text)
         return True, ""
